@@ -28,7 +28,7 @@ class V4l2Capture : public V4l2Access
 		virtual ~V4l2Capture();
 	
 		size_t read(char* buffer, size_t bufferSize);
-		int    isReadable(timeval* tv);	
+		bool   isReadable(timeval* tv);	
 };
 
 
